@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*- 
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * gdl-dock-object.h - Abstract base class for all dock related objects
  *
@@ -37,6 +37,16 @@ G_BEGIN_DECLS
 #define GDL_DOCK_OBJECT_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_DOCK_OBJECT, GdlDockObjectClass))
 
 /* data types & structures */
+
+/**
+ * GdlDockParamFlags:
+ * @GDL_DOCK_PARAM_EXPORT: The parameter is to be exported for later layout rebuilding
+ * @GDL_DOCK_PARAM_AFTER: The parameter must be set after adding the children objects
+ *
+ * Used to flag additional characteristics to GObject properties used in dock
+ * object.
+ *
+ **/
 typedef enum {
     /* the parameter is to be exported for later layout rebuilding */
     GDL_DOCK_PARAM_EXPORT = 1 << G_PARAM_USER_SHIFT,
@@ -47,15 +57,52 @@ typedef enum {
 #define GDL_DOCK_NAME_PROPERTY    "name"
 #define GDL_DOCK_MASTER_PROPERTY  "master"
 
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GdlDockObjectFlags:
+ * @GDL_DOCK_AUTOMATIC: Object is created and destroyed by the master, not the user
+ * @GDL_DOCK_ATTACHED: Object has a parent
+ * @GDL_DOCK_IN_REFLOW: Object is currently part of a rearrangement
+ * @GDL_DOCK_IN_DETACH: Object will be removed
+ *
+ * Described the state of a #GdlDockObject.
+ *
+ * Since 3.6: These flags are available using access function, like
+ * gdl_dock_object_is_automatic() or gdl_dock_object_is_closed().
+ */
 typedef enum {
     GDL_DOCK_AUTOMATIC  = 1 << 0,
     GDL_DOCK_ATTACHED   = 1 << 1,
     GDL_DOCK_IN_REFLOW  = 1 << 2,
     GDL_DOCK_IN_DETACH  = 1 << 3
 } GdlDockObjectFlags;
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_FLAGS_SHIFT:
+ *
+ * Minimum shift count to be used for user defined flags, to be stored in
+ * #GdlDockObject.flags.
+ *
+ * Deprecated: 3.6: Use a private flag instead
+ */
 #define GDL_DOCK_OBJECT_FLAGS_SHIFT 8
+#endif
 
+/**
+ * GdlDockPlacement:
+ * @GDL_DOCK_NONE: No position defined
+ * @GDL_DOCK_TOP: Dock object on the top
+ * @GDL_DOCK_BOTTOM: Dock object on the bottom
+ * @GDL_DOCK_RIGHT: Dock object on the right
+ * @GDL_DOCK_LEFT: Dock object on the left
+ * @GDL_DOCK_CENTER: Dock object on top of the other
+ * @GDL_DOCK_FLOATING: Dock object in its own window
+ *
+ * Described the docking position.
+ *
+ **/
 typedef enum {
     GDL_DOCK_NONE = 0,
     GDL_DOCK_TOP,
@@ -66,10 +113,22 @@ typedef enum {
     GDL_DOCK_FLOATING
 } GdlDockPlacement;
 
-typedef struct _GdlDockObject      GdlDockObject;
-typedef struct _GdlDockObjectClass GdlDockObjectClass;
-typedef struct _GdlDockRequest     GdlDockRequest;
+typedef struct _GdlDockObject             GdlDockObject;
+typedef struct _GdlDockObjectPrivate      GdlDockObjectPrivate;
+typedef struct _GdlDockObjectClass        GdlDockObjectClass;
+typedef struct _GdlDockObjectClassPrivate GdlDockObjectClassPrivate;
+typedef struct _GdlDockRequest            GdlDockRequest;
 
+/**
+ * GdlDockRequest:
+ * @applicant: A #GdlDockObject to dock
+ * @target: The #GdlDockObject target
+ * @position: how to dock @applicant in @target
+ * @rect: Precise position
+ * @extra: Additional information
+ *
+ * Full docking information.
+ **/
 struct _GdlDockRequest {
     GdlDockObject               *applicant;
     GdlDockObject               *target;
@@ -80,23 +139,20 @@ struct _GdlDockRequest {
 
 struct _GdlDockObject {
     GtkContainer        container;
-
-    GdlDockObjectFlags  flags;
-    gint                freeze_count;
-    
-    GObject            *master;
-    gchar              *name;
-    gchar              *long_name;
-    gchar              *stock_id;
-    
-    gboolean            reduce_pending;
+#ifndef GDL_DISABLE_DEPRECATED
+    /* Just for compiling, these data are not initialized anymore */
+    GdlDockObjectFlags  deprecated_flags;
+    GObject            *deprecated_master;
+#endif
+    /*< private >*/
+    GdlDockObjectPrivate  *priv;
 };
 
 struct _GdlDockObjectClass {
     GtkContainerClass parent_class;
 
-    gboolean          is_compound;
-    
+    GdlDockObjectClassPrivate *priv;
+
     void     (* detach)          (GdlDockObject    *object,
                                   gboolean          recursive);
     void     (* reduce)          (GdlDockObject    *object);
@@ -110,7 +166,7 @@ struct _GdlDockObjectClass {
                                   GdlDockObject    *requestor,
                                   GdlDockPlacement  position,
                                   GValue           *other_data);
-    
+
     gboolean (* reorder)         (GdlDockObject    *object,
                                   GdlDockObject    *child,
                                   GdlDockPlacement  new_position,
@@ -125,26 +181,114 @@ struct _GdlDockObjectClass {
 };
 
 /* additional macros */
-#define GDL_DOCK_OBJECT_FLAGS(obj)  (GDL_DOCK_OBJECT (obj)->flags)
-#define GDL_DOCK_OBJECT_AUTOMATIC(obj) \
-    ((GDL_DOCK_OBJECT_FLAGS (obj) & GDL_DOCK_AUTOMATIC) != 0)
-#define GDL_DOCK_OBJECT_ATTACHED(obj) \
-    ((GDL_DOCK_OBJECT_FLAGS (obj) & GDL_DOCK_ATTACHED) != 0)
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_FLAGS:
+ * @obj: A #GdlDockObject
+ *
+ * Get all flags of #GdlDockObject.
+ *
+ * Deprecated: 3.6: The flags are not accessible anymore.
+ */
+#define GDL_DOCK_OBJECT_FLAGS(obj)  (GDL_DOCK_OBJECT (obj)->deprecated_flags)
+#endif
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_AUTOMATIC:
+ * @obj: A #GdlDockObject
+ *
+ * Evaluates to %TRUE if the object's lifecycle is entirely managed by the dock
+ * master.
+ *
+ * Deprecated: 3.6: Use gdl_dock_object_is_automatic()
+ */
+#define GDL_DOCK_OBJECT_AUTOMATIC(obj) gdl_dock_object_is_automatic (GDL_DOCK_OBJECT (obj))
+#endif
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_ATTACHED:
+ * @obj: A #GdlDockObject
+ *
+ * Evaluates to %TRUE if the object has a parent.
+ *
+ * Deprecated: 3.6: Use
+ */
+#define GDL_DOCK_OBJECT_ATTACHED(obj) (!gdl_dock_object_is_closed(GDL_DOCK_OBJECT (obj)))
+#endif
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_IN_REFLOW:
+ * @obj: A #GdlDockObject
+ *
+ * Evaluates to %TRUE if the object is currently rearranged.
+ *
+ * Deprecated: 3.6: Use gdl_dock_object_is_frozen()
+ */
 #define GDL_DOCK_OBJECT_IN_REFLOW(obj) \
     ((GDL_DOCK_OBJECT_FLAGS (obj) & GDL_DOCK_IN_REFLOW) != 0)
+#endif
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_IN_DETACH:
+ * @obj: A #GdlDockObject
+ *
+ * Evaluates to %TRUE if the object will be detached.
+ *
+ * Deprecated: 3.6: This flag is no longer available
+ */
 #define GDL_DOCK_OBJECT_IN_DETACH(obj) \
     ((GDL_DOCK_OBJECT_FLAGS (obj) & GDL_DOCK_IN_DETACH) != 0)
+#endif
 
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_SET_FLAGS:
+ * @obj: A #GdlDockObject
+ * @flag: One or more #GdlDockObjectFlags
+ *
+ * Set one or more flags of a dock object.
+ *
+ * Deprecated: 3.6: This flags are no longer accessible.
+ */
 #define GDL_DOCK_OBJECT_SET_FLAGS(obj,flag) \
     G_STMT_START { (GDL_DOCK_OBJECT_FLAGS (obj) |= (flag)); } G_STMT_END
+#endif
+
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_UNSET_FLAGS:
+ * @obj: A #GdlDockObject
+ * @flag: One or more #GdlDockObjectFlags
+ *
+ * Clear one or more flags of a dock object.
+ *
+ * Deprecated: 3.6: This flags are no longer accessible.
+ */
 #define GDL_DOCK_OBJECT_UNSET_FLAGS(obj,flag) \
     G_STMT_START { (GDL_DOCK_OBJECT_FLAGS (obj) &= ~(flag)); } G_STMT_END
- 
-#define GDL_DOCK_OBJECT_FROZEN(obj) (GDL_DOCK_OBJECT (obj)->freeze_count > 0)
+#endif
+
+#ifndef GDL_DISABLE_DEPRECATED
+/**
+ * GDL_DOCK_OBJECT_FROZEN:
+ * @obj: A #GdlDockObject
+ *
+ * Evaluates to %TRUE if the object is frozen.
+ *
+ * Deprecated: 3.6: Use gdl_dock_object_is_frozen()
+ */
+#define GDL_DOCK_OBJECT_FROZEN(obj) gdl_dock_object_is_frozen(GDL_DOCK_OBJECT (obj))
+#endif
 
 
 /* public interface */
- 
+
 GType          gdl_dock_object_get_type          (void);
 
 gboolean       gdl_dock_object_is_compound       (GdlDockObject    *object);
@@ -156,6 +300,7 @@ GdlDockObject *gdl_dock_object_get_parent_object (GdlDockObject    *object);
 
 void           gdl_dock_object_freeze            (GdlDockObject    *object);
 void           gdl_dock_object_thaw              (GdlDockObject    *object);
+gboolean       gdl_dock_object_is_frozen          (GdlDockObject    *object);
 
 void           gdl_dock_object_reduce            (GdlDockObject    *object);
 
@@ -172,6 +317,9 @@ void           gdl_dock_object_bind              (GdlDockObject    *object,
                                                   GObject          *master);
 void           gdl_dock_object_unbind            (GdlDockObject    *object);
 gboolean       gdl_dock_object_is_bound          (GdlDockObject    *object);
+GObject       *gdl_dock_object_get_master        (GdlDockObject    *object);
+GdlDockObject *gdl_dock_object_get_controller    (GdlDockObject    *object);
+void           gdl_dock_object_layout_changed_notify (GdlDockObject *object);
 
 gboolean       gdl_dock_object_reorder           (GdlDockObject    *object,
                                                   GdlDockObject    *child,
@@ -185,6 +333,25 @@ gboolean       gdl_dock_object_child_placement   (GdlDockObject    *object,
                                                   GdlDockObject    *child,
                                                   GdlDockPlacement *placement);
 
+gboolean       gdl_dock_object_is_closed         (GdlDockObject    *object);
+
+gboolean       gdl_dock_object_is_automatic      (GdlDockObject    *object);
+void           gdl_dock_object_set_manual        (GdlDockObject    *object);
+
+const gchar   *gdl_dock_object_get_name          (GdlDockObject    *object);
+void           gdl_dock_object_set_name          (GdlDockObject    *object,
+                                                  const gchar      *name);
+const gchar   *gdl_dock_object_get_long_name     (GdlDockObject    *object);
+void           gdl_dock_object_set_long_name     (GdlDockObject    *object,
+                                                  const gchar      *name);
+const gchar   *gdl_dock_object_get_stock_id      (GdlDockObject    *object);
+void           gdl_dock_object_set_stock_id      (GdlDockObject    *object,
+                                                  const gchar      *stock_id);
+GdkPixbuf     *gdl_dock_object_get_pixbuf        (GdlDockObject    *object);
+void           gdl_dock_object_set_pixbuf        (GdlDockObject    *object,
+                                                  GdkPixbuf        *icon);
+
+
 /* other types */
 
 /* this type derives from G_TYPE_STRING and is meant to be the basic
@@ -202,6 +369,14 @@ GType                 gdl_dock_object_set_type_for_nick (const gchar *nick,
 
 
 /* helper macros */
+/**
+ * GDL_TRACE_OBJECT:
+ * @object: A #GdlDockObject
+ * @format: Additional printf format string
+ * @...: Additional arguments
+ *
+ * Output a debugging message for the corresponding dock object.
+ */
 #define GDL_TRACE_OBJECT(object, format, args...) \
     G_STMT_START {                            \
     g_log (G_LOG_DOMAIN,                      \
@@ -213,9 +388,9 @@ GType                 gdl_dock_object_set_type_for_nick (const gchar *nick,
            G_OBJECT_TYPE_NAME (object), object, \
            G_OBJECT (object)->ref_count, \
            (GTK_IS_OBJECT (object) && g_object_is_floating (object)) ? "(float)" : "", \
-           GDL_IS_DOCK_OBJECT (object) ? GDL_DOCK_OBJECT (object)->freeze_count : -1, \
-	   ##args); } G_STMT_END                   
-    
+           GDL_IS_DOCK_OBJECT (object) ? gdl_dock_object_is_frozen (GDL_DOCK_OBJECT (object)) : -1, \
+	   ##args); } G_STMT_END
+
 
 
 G_END_DECLS
